Correlation
===========
.. automodule:: lsl.correlator.fx

Baseline Utilities
------------------
.. autofunction:: lsl.correlator.uvUtils.getBaselines
.. autofunction:: lsl.correlator.uvUtils.baseline2antenna
.. autofunction:: lsl.correlator.uvUtils.antenna2baseline

Computing *uvw* Coordinates
---------------------------
.. autofunction:: lsl.correlator.uvUtils.computeUVW
.. autofunction:: lsl.correlator.uvUtils.computeUVTrack

Polyphase Filter Bank
---------------------
.. automodule:: lsl.correlator.filterbank
   :members:

FX Correlator
-------------
.. autofunction:: lsl.correlator.fx.noWindow
.. autofunction:: lsl.correlator.fx.FXMaster
.. autofunction:: lsl.correlator.fx.FXStokes

